@@ -14,3 +14,10 @@ def sel_dims(sel, dims):
 			isinstance(sel[dim], np.ndarray) or \
 			type(sel[dim]) in (list, tuple)
 	]
+
+def encoder(x):
+	if isinstance(x, np.generic):
+		return x.item()
+	elif isinstance(x, np.ndarray):
+		return x.tolist()
+	return x
